@@ -327,6 +327,55 @@ purple_conversation_chat_cleanup_for_rejoin(PurpleConversation *conv)
 	purple_conversation_update(conv, PURPLE_CONV_UPDATE_CHATLEFT);
 }
 
+/* Meaningful name in case a UI doesn't actually honour the INVISIBLE flag */
+#define TRANSIENT_GROUP_NAME _("(internal) Temporary IM peers")
+
+static void
+purple_conversation_ensure_buddy(PurpleAccount *account, PurpleConnection *gc,
+				 const char *name)
+{
+	PurplePluginProtocolInfo *prpl_info;
+	PurpleBuddy *buddy;
+	PurpleGroup *group;
+
+	prpl_info = PURPLE_PLUGIN_PROTOCOL_INFO(purple_connection_get_prpl(gc));
+
+	if ((prpl_info->options & OPT_PROTO_TRANSIENT_BUDDIES) &&
+	    !purple_find_buddy(account, name)) {
+		group = purple_find_group(TRANSIENT_GROUP_NAME);
+		if (!group) {
+			group = purple_group_new(TRANSIENT_GROUP_NAME);
+			purple_blist_node_set_flags(PURPLE_BLIST_NODE(group),
+						    PURPLE_BLIST_NODE_FLAG_NO_SAVE | PURPLE_BLIST_NODE_FLAG_INVISIBLE);
+			purple_blist_add_group(group, NULL);
+		}
+		buddy = purple_buddy_new(account, name, NULL);
+		purple_blist_node_set_flags(PURPLE_BLIST_NODE(buddy),
+					    PURPLE_BLIST_NODE_FLAG_NO_SAVE | PURPLE_BLIST_NODE_FLAG_INVISIBLE);
+
+		purple_blist_add_buddy(buddy, NULL, group, NULL);
+		purple_account_add_buddy(account, buddy);
+	}
+}
+
+static void
+purple_conversation_release_buddy(PurpleAccount *account, const char *name)
+{
+	PurpleBuddy *buddy;
+	PurpleGroup *group;
+
+	group = purple_find_group(TRANSIENT_GROUP_NAME);
+	if (!group)
+		return;
+
+	buddy = purple_find_buddy_in_group(account, name, group);
+	if (!buddy)
+		return;
+
+	purple_account_remove_buddy(account, buddy, group);
+	purple_blist_remove_buddy(buddy);
+}
+
 PurpleConversation *
 purple_conversation_new(PurpleConversationType type, PurpleAccount *account,
 					  const char *name)
@@ -403,6 +452,8 @@ purple_conversation_new(PurpleConversationType type, PurpleAccount *account,
 			purple_conversation_set_logging(conv, TRUE);
 			open_log(conv);
 		}
+
+		purple_conversation_ensure_buddy(account, gc, name);
 	}
 	else if (type == PURPLE_CONV_TYPE_CHAT)
 	{
@@ -484,6 +535,8 @@ purple_conversation_destroy(PurpleConversation *conv)
 
 			if (gc && prpl_info->convo_closed != NULL)
 				prpl_info->convo_closed(gc, name);
+
+			purple_conversation_release_buddy(conv->account, conv->name);
 		}
 		else if (purple_conversation_get_type(conv) == PURPLE_CONV_TYPE_CHAT)
 		{
@@ -933,6 +986,7 @@ purple_conversation_write(PurpleConversation *conv, const char *who,
 	PurpleConnection *gc = NULL;
 	PurpleAccount *account;
 	PurpleConversationUiOps *ops;
+	char *server_alias = NULL;
 	const char *alias;
 	char *displayed = NULL;
 	PurpleBuddy *b;
@@ -1006,6 +1060,13 @@ purple_conversation_write(PurpleConversation *conv, const char *who,
 					alias = purple_buddy_get_contact_alias(b);
 			}
 		}
+		if (purple_conversation_get_type(conv) == PURPLE_CONV_TYPE_CHAT &&
+		    alias == who && PURPLE_PROTOCOL_PLUGIN_HAS_FUNC(prpl_info, get_cb_alias)) {
+			int id = purple_conv_chat_get_id(PURPLE_CONV_CHAT(conv));
+			server_alias = prpl_info->get_cb_alias(gc, id, who);
+			if (server_alias)
+				alias = server_alias;
+		}
 	}
 
 	if (!(flags & PURPLE_MESSAGE_NO_LOG) && purple_conversation_is_logging(conv)) {
@@ -1031,6 +1092,7 @@ purple_conversation_write(PurpleConversation *conv, const char *who,
 		account, who, displayed, conv, flags);
 
 	g_free(displayed);
+	g_free(server_alias);
 }
 
 gboolean
@@ -1678,6 +1740,7 @@ purple_conv_chat_add_users(PurpleConvChat *chat, GList *users, GList *extra_msgs
 	while ((ul != NULL) && (fl != NULL)) {
 		const char *user = (const char *)ul->data;
 		const char *alias = user;
+		char *server_alias = NULL;
 		gboolean quiet;
 		PurpleConvChatBuddyFlags flag = GPOINTER_TO_INT(fl->data);
 		const char *extra_msg = (extra_msgs ? extra_msgs->data : NULL);
@@ -1699,6 +1762,12 @@ purple_conv_chat_add_users(PurpleConvChat *chat, GList *users, GList *extra_msgs
 					alias = purple_buddy_get_contact_alias(buddy);
 			}
 		}
+		if (alias == user && PURPLE_PROTOCOL_PLUGIN_HAS_FUNC(prpl_info, get_cb_alias)) {
+			int id = purple_conv_chat_get_id(PURPLE_CONV_CHAT(conv));
+			server_alias = prpl_info->get_cb_alias(gc, id, user);
+			if (server_alias)
+				alias = server_alias;
+		}
 
 		quiet = GPOINTER_TO_INT(purple_signal_emit_return_1(purple_conversations_get_handle(),
 						 "chat-buddy-joining", conv, user, flag)) ||
@@ -1738,6 +1807,8 @@ purple_conv_chat_add_users(PurpleConvChat *chat, GList *users, GList *extra_msgs
 		fl = fl->next;
 		if (extra_msgs != NULL)
 			extra_msgs = extra_msgs->next;
+
+		g_free(server_alias);
 	}
 
 	cbuddies = g_list_sort(cbuddies, (GCompareFunc)purple_conv_chat_cb_compare);
@@ -1759,6 +1830,7 @@ purple_conv_chat_rename_user(PurpleConvChat *chat, const char *old_user,
 	PurpleConvChatBuddy *cb;
 	PurpleConvChatBuddyFlags flags;
 	const char *new_alias = new_user;
+	char *server_alias = NULL;
 	char tmp[BUF_LONG];
 	gboolean is_me = FALSE;
 
@@ -1791,10 +1863,18 @@ purple_conv_chat_rename_user(PurpleConvChat *chat, const char *old_user,
 					alias = display_name;
 			}
 		}
-	} else if (!(prpl_info->options & OPT_PROTO_UNIQUE_CHATNAME)) {
-		PurpleBuddy *buddy;
-		if ((buddy = purple_find_buddy(gc->account, new_user)) != NULL)
-			new_alias = purple_buddy_get_contact_alias(buddy);
+	} else {
+		if (!(prpl_info->options & OPT_PROTO_UNIQUE_CHATNAME)) {
+			PurpleBuddy *buddy;
+			if ((buddy = purple_find_buddy(gc->account, new_user)) != NULL)
+				new_alias = purple_buddy_get_contact_alias(buddy);
+		}
+		if (new_alias == new_user && PURPLE_PROTOCOL_PLUGIN_HAS_FUNC(prpl_info, get_cb_alias)) {
+			int id = purple_conv_chat_get_id(PURPLE_CONV_CHAT(conv));
+			server_alias = prpl_info->get_cb_alias(gc, id, new_user);
+			if (server_alias)
+				new_alias = server_alias;
+		}
 	}
 
 	flags = purple_conv_chat_user_get_flags(chat, old_user);
@@ -1860,6 +1940,7 @@ purple_conv_chat_rename_user(PurpleConvChat *chat, const char *old_user,
 				PURPLE_MESSAGE_SYSTEM | PURPLE_MESSAGE_NO_LINKIFY,
 				time(NULL));
 	}
+	g_free(server_alias);
 }
 
 void
@@ -1913,6 +1994,7 @@ purple_conv_chat_remove_users(PurpleConvChat *chat, GList *users, const char *re
 
 		if (!quiet) {
 			const char *alias = user;
+			char *server_alias = NULL;
 			char *alias_esc;
 			char *tmp;
 
@@ -1922,6 +2004,12 @@ purple_conv_chat_remove_users(PurpleConvChat *chat, GList *users, const char *re
 				if ((buddy = purple_find_buddy(gc->account, user)) != NULL)
 					alias = purple_buddy_get_contact_alias(buddy);
 			}
+			if (alias == user && PURPLE_PROTOCOL_PLUGIN_HAS_FUNC(prpl_info, get_cb_alias)) {
+				int id = purple_conv_chat_get_id(PURPLE_CONV_CHAT(conv));
+				server_alias = prpl_info->get_cb_alias(gc, id, user);
+				if (server_alias)
+					alias = server_alias;
+			}
 
 			alias_esc = g_markup_escape_text(alias, -1);
 
@@ -1934,6 +2022,7 @@ purple_conv_chat_remove_users(PurpleConvChat *chat, GList *users, const char *re
 				g_free(reason_esc);
 			}
 			g_free(alias_esc);
+			g_free(server_alias);
 
 			purple_conversation_write(conv, NULL, tmp,
 					PURPLE_MESSAGE_SYSTEM | PURPLE_MESSAGE_NO_LINKIFY,
