@@ -47,9 +47,6 @@
  */
 #ifdef ENABLE_NLS
 #  include <locale.h>
-#  ifndef __APPLE_CC__
-#    define __APPLE_CC__ 0
-#  endif
 #  include <libintl.h>
 #  define _(String) ((const char *)dgettext(PACKAGE, String))
 #  ifdef gettext_noop
@@ -127,14 +124,7 @@
 
 #include <glib.h>
 
-/* This wasn't introduced until Glib 2.14 :( */
-#ifndef G_MAXSSIZE
-#	if GLIB_SIZEOF_LONG == 8
-#		define G_MAXSSIZE ((gssize) 0x7fffffffffffffff)
-#	else
-#		define G_MAXSSIZE ((gssize) 0x7fffffff)
-#	endif
-#endif
+#include "glibcompat.h"
 
 #include <glib/gstdio.h>
 
@@ -154,26 +144,6 @@
 
 #include <glib-object.h>
 
-#if !GLIB_CHECK_VERSION(2, 32, 0)
-
-#define G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-#define G_GNUC_END_IGNORE_DEPRECATIONS
-
-#endif /* 2.32.0 */
-
-#ifdef __clang__
-
-#undef G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-#define G_GNUC_BEGIN_IGNORE_DEPRECATIONS \
-	_Pragma ("clang diagnostic push") \
-	_Pragma ("clang diagnostic ignored \"-Wdeprecated-declarations\"")
-
-#undef G_GNUC_END_IGNORE_DEPRECATIONS
-#define G_GNUC_END_IGNORE_DEPRECATIONS \
-	_Pragma ("clang diagnostic pop")
-
-#endif /* __clang__ */
-
 #ifdef __COVERITY__
 
 /* avoid TAINTED_SCALAR warning */
