@@ -71,9 +71,9 @@ _find_resolver_data(gconstpointer a, gconstpointer b) {
 
 	if(rd_a->interface == rd_b->interface
 			&& rd_a->protocol == rd_b->protocol
-			&& !strcmp(rd_a->name, rd_b->name)
-			&& !strcmp(rd_a->type, rd_b->type)
-			&& !strcmp(rd_a->domain, rd_b->domain)) {
+			&& purple_strequal(rd_a->name, rd_b->name)
+			&& purple_strequal(rd_a->type, rd_b->type)
+			&& purple_strequal(rd_a->domain, rd_b->domain)) {
 		ret = 0;
 	}
 
@@ -185,7 +185,7 @@ _resolver_callback(AvahiServiceResolver *r, AvahiIfIndex interface, AvahiProtoco
 			purple_debug_info("bonjour", "_resolve_callback - name:%s ip:%s prev_ip:%s\n",
 				name, ip, rd->ip);
 
-			if (rd->ip == NULL || strcmp(rd->ip, ip) != 0) {
+			if (rd->ip == NULL || !purple_strequal(rd->ip, ip)) {
 				/* We store duplicates in bb->ips, so we always remove the one */
 				if (rd->ip != NULL) {
 					bb->ips = g_slist_remove(bb->ips, rd->ip);
