@@ -218,7 +218,7 @@ JabberBuddyResource *jabber_buddy_find_resource(JabberBuddy *jb,
 	for (l = jb->resources; l; l = l->next)
 	{
 		JabberBuddyResource *jbr = l->data;
-		if (jbr->name && g_str_equal(resource, jbr->name))
+		if (purple_strequal(resource, jbr->name))
 			return jbr;
 	}
 
@@ -407,7 +407,7 @@ static xmlnode *insert_tag_to_parent_tag(xmlnode *start, const char *parent_tag,
 		const struct vcard_template *vc_tp = vcard_template_data;
 
 		while(vc_tp->label != NULL) {
-			if(strcmp(vc_tp->tag, new_tag) == 0) {
+			if(purple_strequal(vc_tp->tag, new_tag)) {
 				parent_tag = vc_tp->ptag;
 				break;
 			}
@@ -653,7 +653,7 @@ void jabber_setup_set_info(PurplePluginAction *action)
 				cdata = xmlnode_get_data(data_node);
 		}
 
-		if(strcmp(vc_tp->tag, "DESC") == 0) {
+		if(purple_strequal(vc_tp->tag, "DESC")) {
 			field = purple_request_field_string_new(vc_tp->tag,
 												  _(vc_tp->label), cdata,
 												  TRUE);
@@ -875,7 +875,7 @@ static void jabber_buddy_info_remove_id(JabberBuddyInfo *jbi, const char *id)
 
 	while(l) {
 		comp_id = l->data;
-		if(!strcmp(id, comp_id)) {
+		if(purple_strequal(id, comp_id)) {
 			jbi->ids = g_slist_remove(jbi->ids, comp_id);
 			g_free(comp_id);
 			return;
@@ -1017,12 +1017,12 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 				continue;
 
 			text = xmlnode_get_data(child);
-			if(text && !strcmp(child->name, "FN")) {
+			if(text && purple_strequal(child->name, "FN")) {
 				if (!serverside_alias)
 					serverside_alias = g_strdup(text);
 
-				purple_notify_user_info_add_pair(user_info, _("Full Name"), text);
-			} else if(!strcmp(child->name, "N")) {
+				purple_notify_user_info_add_pair_plaintext(user_info, _("Full Name"), text);
+			} else if(purple_strequal(child->name, "N")) {
 				for(child2 = child->child; child2; child2 = child2->next)
 				{
 					char *text2;
@@ -1031,27 +1031,27 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 						continue;
 
 					text2 = xmlnode_get_data(child2);
-					if(text2 && !strcmp(child2->name, "FAMILY")) {
-						purple_notify_user_info_add_pair(user_info, _("Family Name"), text2);
-					} else if(text2 && !strcmp(child2->name, "GIVEN")) {
-						purple_notify_user_info_add_pair(user_info, _("Given Name"), text2);
-					} else if(text2 && !strcmp(child2->name, "MIDDLE")) {
-						purple_notify_user_info_add_pair(user_info, _("Middle Name"), text2);
+					if(text2 && purple_strequal(child2->name, "FAMILY")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Family Name"), text2);
+					} else if(text2 && purple_strequal(child2->name, "GIVEN")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Given Name"), text2);
+					} else if(text2 && purple_strequal(child2->name, "MIDDLE")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Middle Name"), text2);
 					}
 					g_free(text2);
 				}
-			} else if(text && !strcmp(child->name, "NICKNAME")) {
+			} else if(text && purple_strequal(child->name, "NICKNAME")) {
 				/* Prefer the Nickcname to the Full Name as the serverside alias if it's not just part of the jid.
 				 * Ignore it if it's part of the jid. */
 				if (strstr(bare_jid, text) == NULL) {
 					g_free(serverside_alias);
 					serverside_alias = g_strdup(text);
 
-					purple_notify_user_info_add_pair(user_info, _("Nickname"), text);
+					purple_notify_user_info_add_pair_plaintext(user_info, _("Nickname"), text);
 				}
-			} else if(text && !strcmp(child->name, "BDAY")) {
-				purple_notify_user_info_add_pair(user_info, _("Birthday"), text);
-			} else if(!strcmp(child->name, "ADR")) {
+			} else if(text && purple_strequal(child->name, "BDAY")) {
+				purple_notify_user_info_add_pair_plaintext(user_info, _("Birthday"), text);
+			} else if(purple_strequal(child->name, "ADR")) {
 				gboolean address_line_added = FALSE;
 
 				for(child2 = child->child; child2; child2 = child2->next)
@@ -1073,26 +1073,26 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 						address_line_added = TRUE;
 					}
 
-					if(!strcmp(child2->name, "POBOX")) {
-						purple_notify_user_info_add_pair(user_info, _("P.O. Box"), text2);
-					} else if (g_str_equal(child2->name, "EXTADD") || g_str_equal(child2->name, "EXTADR")) {
+					if(purple_strequal(child2->name, "POBOX")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("P.O. Box"), text2);
+					} else if (purple_strequal(child2->name, "EXTADD") || purple_strequal(child2->name, "EXTADR")) {
 						/*
 						 * EXTADD is correct, EXTADR is generated by other
 						 * clients. The next time someone reads this, remove
 						 * EXTADR.
 						 */
-						purple_notify_user_info_add_pair(user_info, _("Extended Address"), text2);
-					} else if(!strcmp(child2->name, "STREET")) {
-						purple_notify_user_info_add_pair(user_info, _("Street Address"), text2);
-					} else if(!strcmp(child2->name, "LOCALITY")) {
-						purple_notify_user_info_add_pair(user_info, _("Locality"), text2);
-					} else if(!strcmp(child2->name, "REGION")) {
-						purple_notify_user_info_add_pair(user_info, _("Region"), text2);
-					} else if(!strcmp(child2->name, "PCODE")) {
-						purple_notify_user_info_add_pair(user_info, _("Postal Code"), text2);
-					} else if(!strcmp(child2->name, "CTRY")
-								|| !strcmp(child2->name, "COUNTRY")) {
-						purple_notify_user_info_add_pair(user_info, _("Country"), text2);
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Extended Address"), text2);
+					} else if(purple_strequal(child2->name, "STREET")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Street Address"), text2);
+					} else if(purple_strequal(child2->name, "LOCALITY")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Locality"), text2);
+					} else if(purple_strequal(child2->name, "REGION")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Region"), text2);
+					} else if(purple_strequal(child2->name, "PCODE")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Postal Code"), text2);
+					} else if(purple_strequal(child2->name, "CTRY")
+								|| purple_strequal(child2->name, "COUNTRY")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Country"), text2);
 					}
 					g_free(text2);
 				}
@@ -1100,22 +1100,22 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 				if (address_line_added)
 					purple_notify_user_info_add_section_break(user_info);
 
-			} else if(!strcmp(child->name, "TEL")) {
+			} else if(purple_strequal(child->name, "TEL")) {
 				char *number;
 				if((child2 = xmlnode_get_child(child, "NUMBER"))) {
 					/* show what kind of number it is */
 					number = xmlnode_get_data(child2);
 					if(number) {
-						purple_notify_user_info_add_pair(user_info, _("Telephone"), number);
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Telephone"), number);
 						g_free(number);
 					}
 				} else if((number = xmlnode_get_data(child))) {
 					/* lots of clients (including purple) do this, but it's
 					 * out of spec */
-					purple_notify_user_info_add_pair(user_info, _("Telephone"), number);
+					purple_notify_user_info_add_pair_plaintext(user_info, _("Telephone"), number);
 					g_free(number);
 				}
-			} else if(!strcmp(child->name, "EMAIL")) {
+			} else if(purple_strequal(child->name, "EMAIL")) {
 				char *userid, *escaped;
 				if((child2 = xmlnode_get_child(child, "USERID"))) {
 					/* show what kind of email it is */
@@ -1143,7 +1143,7 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 					g_free(escaped);
 					g_free(userid);
 				}
-			} else if(!strcmp(child->name, "ORG")) {
+			} else if(purple_strequal(child->name, "ORG")) {
 				for(child2 = child->child; child2; child2 = child2->next)
 				{
 					char *text2;
@@ -1152,21 +1152,21 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 						continue;
 
 					text2 = xmlnode_get_data(child2);
-					if(text2 && !strcmp(child2->name, "ORGNAME")) {
-						purple_notify_user_info_add_pair(user_info, _("Organization Name"), text2);
-					} else if(text2 && !strcmp(child2->name, "ORGUNIT")) {
-						purple_notify_user_info_add_pair(user_info, _("Organization Unit"), text2);
+					if(text2 && purple_strequal(child2->name, "ORGNAME")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Organization Name"), text2);
+					} else if(text2 && purple_strequal(child2->name, "ORGUNIT")) {
+						purple_notify_user_info_add_pair_plaintext(user_info, _("Organization Unit"), text2);
 					}
 					g_free(text2);
 				}
-			} else if(text && !strcmp(child->name, "TITLE")) {
-				purple_notify_user_info_add_pair(user_info, _("Job Title"), text);
-			} else if(text && !strcmp(child->name, "ROLE")) {
-				purple_notify_user_info_add_pair(user_info, _("Role"), text);
-			} else if(text && !strcmp(child->name, "DESC")) {
-				purple_notify_user_info_add_pair(user_info, _("Description"), text);
-			} else if(!strcmp(child->name, "PHOTO") ||
-					!strcmp(child->name, "LOGO")) {
+			} else if(text && purple_strequal(child->name, "TITLE")) {
+				purple_notify_user_info_add_pair_plaintext(user_info, _("Job Title"), text);
+			} else if(text && purple_strequal(child->name, "ROLE")) {
+				purple_notify_user_info_add_pair_plaintext(user_info, _("Role"), text);
+			} else if(text && purple_strequal(child->name, "DESC")) {
+				purple_notify_user_info_add_pair_plaintext(user_info, _("Description"), text);
+			} else if(purple_strequal(child->name, "PHOTO") ||
+					purple_strequal(child->name, "LOGO")) {
 				char *bintext = NULL;
 				xmlnode *binval;
 
@@ -1174,7 +1174,7 @@ static void jabber_vcard_parse(JabberStream *js, const char *from,
 						(bintext = xmlnode_get_data(binval))) {
 					gsize size;
 					guchar *data;
-					gboolean photo = (strcmp(child->name, "PHOTO") == 0);
+					gboolean photo = purple_strequal(child->name, "PHOTO");
 
 					data = purple_base64_decode(bintext, &size);
 					if (data) {
@@ -1481,12 +1481,12 @@ static gboolean _client_is_blacklisted(JabberBuddyResource *jbr, const char *ns)
 	if(!jbr->client.name)
 		return FALSE;
 
-	if(!strcmp(ns, NS_LAST_ACTIVITY)) {
-		if(!strcmp(jbr->client.name, "Trillian")) {
+	if(purple_strequal(ns, NS_LAST_ACTIVITY)) {
+		if(purple_strequal(jbr->client.name, "Trillian")) {
 			/* verified by nwalp 2007/05/09 */
-			if(!strcmp(jbr->client.version, "3.1.0.121") ||
+			if(purple_strequal(jbr->client.version, "3.1.0.121") ||
 					/* verified by nwalp 2007/09/19 */
-					!strcmp(jbr->client.version, "3.1.7.0")) {
+					purple_strequal(jbr->client.version, "3.1.7.0")) {
 				return TRUE;
 			}
 		}
@@ -1974,7 +1974,7 @@ static void user_search_result_cb(JabberStream *js, const char *from,
 						field = xmlnode_get_next_twin(field))
 				{
 					if ((var = xmlnode_get_attrib(field, "var")) &&
-							!strcmp(var, l->data) &&
+							purple_strequal(var, l->data) &&
 							(valuenode = xmlnode_get_child(field, "value")))
 					{
 						char *value = xmlnode_get_data(valuenode);
@@ -2045,7 +2045,7 @@ static void user_search_x_data_cb(JabberStream *js, xmlnode *result, gpointer da
 	 * just going to get an error if we send
 	 * a cancel, so skip it */
 	type = xmlnode_get_attrib(result, "type");
-	if(type && !strcmp(type, "cancel")) {
+	if(purple_strequal(type, "cancel")) {
 		g_free(dir_server);
 		return;
 	}
@@ -2089,7 +2089,7 @@ static void user_search_cb(struct user_search_info *usi, PurpleRequestFields *fi
 			const char *id = purple_request_field_get_id(field);
 			const char *value = purple_request_field_string_get_value(field);
 
-			if(value && (!strcmp(id, "first") || !strcmp(id, "last") || !strcmp(id, "nick") || !strcmp(id, "email"))) {
+			if(value && (purple_strequal(id, "first") || purple_strequal(id, "last") || purple_strequal(id, "nick") || purple_strequal(id, "email"))) {
 				xmlnode *y = xmlnode_new_child(query, id);
 				xmlnode_insert_data(y, value, -1);
 			}
@@ -2229,6 +2229,16 @@ void jabber_user_search(JabberStream *js, const char *directory)
 		return;
 	}
 
+	/* If the value provided isn't the disco#info default, persist it.  Otherwise,
+	   make sure we aren't persisting an old value */
+	if(js->user_directories && js->user_directories->data &&
+	   purple_strequal(directory, js->user_directories->data)) {
+		purple_account_set_string(js->gc->account, "user_directory", "");
+	}
+	else {
+		purple_account_set_string(js->gc->account, "user_directory", directory);
+	}
+
 	iq = jabber_iq_new_query(js, JABBER_IQ_GET, "jabber:iq:search");
 	xmlnode_set_attrib(iq->node, "to", directory);
 
@@ -2241,10 +2251,13 @@ void jabber_user_search_begin(PurplePluginAction *action)
 {
 	PurpleConnection *gc = (PurpleConnection *) action->context;
 	JabberStream *js = purple_connection_get_protocol_data(gc);
+	const char *def_val = purple_account_get_string(js->gc->account, "user_directory", "");
+	if(!*def_val && js->user_directories)
+		def_val = js->user_directories->data;
 
 	purple_request_input(gc, _("Enter a User Directory"), _("Enter a User Directory"),
 			_("Select a user directory to search"),
-			js->user_directories ? js->user_directories->data : NULL,
+			def_val,
 			FALSE, FALSE, NULL,
 			_("Search Directory"), PURPLE_CALLBACK(jabber_user_search),
 			_("Cancel"), NULL,
@@ -2311,7 +2324,7 @@ jabber_resource_get_identity_category_type(const JabberBuddyResource *jbr,
 			const JabberIdentity *identity =
 				(JabberIdentity *) iter->data;
 
-			if (strcmp(identity->category, category) == 0) {
+			if (purple_strequal(identity->category, category)) {
 				return identity->type;
 			}
 		}
