@@ -49,6 +49,8 @@ typedef enum {
 	JABBER_CAP_ITEMS          = 1 << 14,
 	JABBER_CAP_ROSTER_VERSIONING = 1 << 15,
 
+	JABBER_CAP_STREAM_MANAGEMENT = 1 << 16,
+
 	JABBER_CAP_RETRIEVED      = 1 << 31
 } JabberCapabilities;
 
@@ -96,6 +98,12 @@ typedef enum {
 	JABBER_STREAM_CONNECTED
 } JabberStreamState;
 
+typedef enum {
+	SM_DISABLED,
+	SM_REQUESTED,
+	SM_ENABLED
+} JabberStreamManagementState;
+
 struct _JabberStream
 {
 	int fd;
@@ -282,6 +290,12 @@ struct _JabberStream
 	gchar *google_relay_host;
 	GList *google_relay_requests; /* the HTTP requests to get */
 												/* relay info */
+
+	/* XEP-0198 (stream management) state */
+	guint32 sm_outbound_count;
+	guint32 sm_inbound_count;
+	guint32 sm_outbound_confirmed;
+	JabberStreamManagementState sm_state;
 };
 
 typedef gboolean (JabberFeatureEnabled)(JabberStream *js, const gchar *namespace);
@@ -314,6 +328,8 @@ extern GList *jabber_features;
  */
 extern GList *jabber_identities;
 
+gboolean jabber_is_stanza(xmlnode *packet);
+
 void jabber_stream_features_parse(JabberStream *js, xmlnode *packet);
 void jabber_process_packet(JabberStream *js, xmlnode **packet);
 void jabber_send(JabberStream *js, xmlnode *data);
