@@ -605,7 +605,6 @@ peer_connection_listen_cb(gpointer data, gint source, PurpleInputCondition cond)
 	PeerConnection *conn;
 	struct sockaddr addr;
 	socklen_t addrlen = sizeof(addr);
-	int flags;
 
 	conn = data;
 
@@ -630,11 +629,7 @@ peer_connection_listen_cb(gpointer data, gint source, PurpleInputCondition cond)
 		return;
 	}
 
-	flags = fcntl(conn->fd, F_GETFL);
-	fcntl(conn->fd, F_SETFL, flags | O_NONBLOCK);
-#ifndef _WIN32
-	fcntl(conn->fd, F_SETFD, FD_CLOEXEC);
-#endif
+	_purple_network_set_common_socket_flags(conn->fd);
 
 	purple_input_remove(conn->watcher_incoming);
 
@@ -815,7 +810,7 @@ peer_connection_trynext(PeerConnection *conn)
 				peer_connection_verified_established_cb, conn);
 
 		if ((conn->verifiedip == NULL) ||
-			strcmp(conn->verifiedip, conn->clientip))
+			!purple_strequal(conn->verifiedip, conn->clientip))
 		{
 			conn->client_connect_data = purple_proxy_connect(NULL, account,
 					conn->clientip, conn->port,
