@@ -74,23 +74,18 @@ struct artist {
 static const struct developer developers[] = {
 	{"Daniel 'datallah' Atallah",          NULL,                  NULL},
 	{"Paul 'darkrain42' Aurich",           NULL,                  NULL},
+	{"John 'rekkanoryo' Bailey",           NULL,                  NULL},
 	{"Ethan 'Paco-Paco' Blanton",          NULL,                  NULL},
 	{"Hylke Bons",                         N_("artist"),          "hylkebons@gmail.com"},
-	{"Sadrul Habib Chowdhury",             NULL,                  NULL},
-	{"Mark 'KingAnt' Doliner",             NULL,                  "mark@kingant.net"},
-	{"Gary 'grim' Kramlich",               NULL,                  "grim@pidgin.im"},
+	{"Gary 'grim' Kramlich",               N_("lead developer"),  "grim@pidgin.im"},
 	{"Richard 'rlaager' Laager",           NULL,                  "rlaager@pidgin.im"},
 	{"Marcus 'malu' Lundblad",             NULL,                  NULL},
-	{"Sulabh 'sulabh_m' Mahajan",          NULL,                  NULL},
-	{"Richard 'wabz' Nelson",              NULL,                  NULL},
 	{"Etan 'deryni' Reisner",              NULL,                  NULL},
 	{"Michael 'Maiku' Ruprecht",           N_("voice and video"), NULL},
 	{"Elliott 'QuLogic' Sales de Andrade", NULL,                  NULL},
 	{"Luke 'LSchiere' Schierer",           N_("support"),         "lschiere@users.sf.net"},
 	{"Evan Schoenberg",                    NULL,                  NULL},
 	{"Kevin 'SimGuy' Stange",              N_("webmaster"),       NULL},
-	{"Will 'resiak' Thompson",             NULL,                  NULL},
-	{"Stu 'nosnilmot' Tomlinson",          NULL,                  NULL},
 	{"Jorge 'Masca' Villaseñor",           NULL,                  NULL},
 	{"Tomasz Wasilczyk",                   NULL,                  "https://www.wasilczyk.pl"},
 	{NULL, NULL, NULL}
@@ -106,12 +101,13 @@ static const struct developer patch_writers[] = {
 
 /* Order: Alphabetical by Last Name */
 static const struct developer retired_developers[] = {
-	{"John 'rekkanoryo' Bailey",    NULL,                      NULL},
 	{"Herman Bloggs",               N_("win32 port"),          "herman@bluedigits.com"},
 	{"Thomas Butter",               NULL,                      NULL},
 	/* Translators: This is a person's name. For most languages we recommend
 	   not translating it. */
 	{N_("Ka-Hing Cheung"),          NULL,                      NULL},
+	{"Sadrul Habib Chowdhury",      NULL,                      NULL},
+	{"Mark 'KingAnt' Doliner",      NULL,                      "mark@kingant.net"},
 	{"Jim Duchek",                  N_("maintainer"),          "jim@linuxpimps.com"},
 	{"Sean Egan",                   NULL,                      "sean.egan@gmail.com"},
 	{"Rob Flynn",                   N_("maintainer"),          NULL},
@@ -121,12 +117,16 @@ static const struct developer retired_developers[] = {
 	{"Ivan Komarov",                NULL,                      "ivan.komarov@pidgin.im"},
 	/* If "lazy bum" translates literally into a serious insult, use something else or omit it. */
 	{"Syd Logan",                   N_("hacker and designated driver [lazy bum]"), NULL},
+	{"Sulabh 'sulabh_m' Mahajan",   NULL,                      NULL},
+	{"Richard 'wabz' Nelson",       NULL,                      NULL},
 	{"Christopher 'siege' O'Brien", NULL,                      "taliesein@users.sf.net"},
 	{"Bartosz Oler",                NULL,                      NULL},
 	{"Tim 'marv' Ringenbach",       NULL,                      NULL},
 	{"Megan 'Cae' Schneider",       N_("support/QA"),          NULL},
 	{"Jim Seymour",                 N_("XMPP"),                NULL},
 	{"Mark Spencer",                N_("original author"),     "markster@marko.net"},
+	{"Will 'resiak' Thompson",      NULL,                      NULL},
+	{"Stu 'nosnilmot' Tomlinson",   NULL,                      NULL},
 	{"Nathan 'faceprint' Walp",     NULL,                      NULL},
 	{"Eric Warmenhoven",            N_("lead developer"),      "warmenhoven@yahoo.com"},
 	{NULL, NULL, NULL}
