@@ -70,13 +70,16 @@
 #include "pidginstock.h"
 #include "gtkwhiteboard.h"
 
+#ifdef HAVE_X11
+#include <X11/Xlib.h>
+#endif
+
 #ifdef HAVE_SIGNAL_H
 # include <signal.h>
 #endif
 
 #include <getopt.h>
 
-
 #ifdef HAVE_SIGNAL_H
 
 /*
@@ -749,6 +752,11 @@ int main(int argc, char *argv[])
 	gtk_rc_add_default_file(search_path);
 	g_free(search_path);
 
+#if defined(HAVE_X11) && defined(USE_VV)
+	/* GStreamer elements such as ximagesrc may require this */
+	XInitThreads();
+#endif
+
 	gui_check = gtk_init_check(&argc, &argv);
 	if (!gui_check) {
 		char *display = gdk_get_display();
