@@ -25,10 +25,6 @@
  *
  */
 
-/* This is for ATTACH_PARENT_PROCESS */
-#ifndef _WIN32_WINNT
-#define _WIN32_WINNT 0x501
-#endif
 #include <windows.h>
 #include <fcntl.h>
 #include <stdlib.h>
